import os
from celery import Celery
from dotenv import load_dotenv

# Load environment variables from the .env file
load_dotenv()

# Load environment variables
REDIS_HOST = os.getenv('REDIS_HOST', 'localhost')
REDIS_PORT = int(os.getenv('REDIS_PORT', 6379))
REDIS_DB = int(os.getenv('REDIS_DB', 0))
REDIS_PASSWORD = os.getenv('REDIS_PASSWORD', None)

# Construct the Redis URL based on the presence of the password
if REDIS_PASSWORD:
    redis_url = f'redis://{REDIS_PASSWORD}@{REDIS_HOST}:{REDIS_PORT}/{REDIS_DB}'
else:
    redis_url = f'redis://{REDIS_HOST}:{REDIS_PORT}/{REDIS_DB}'

# Create the Celery app
app = Celery(
    'email_server',
    broker=redis_url,
    backend=redis_url,  # Backend set to Redis URL
    task_ignore_result=False,
    result_expires=3600,  # Results available for 1 hour (3600 seconds)
)

# Celery configuration for task routing
app.conf.update(
    task_routes={
        'auth_server.tasks.*': {'queue': 'auth_queue'},
        'email_server.tasks.*': {'queue': 'email_queue'}
    }
)

# Automatically discover tasks in the specified modules
app.autodiscover_tasks(['email_server', 'auth_server'])
