import asyncio
import socketio
from aiohttp import web
from apps.auth.urls import setup_routes as auth_routes
from apps.system.urls import setup_routes as system_routes
from config.database import Base, engine
# from events import register_socketio_events

# Create an ASGI-compatible server with aiohttp
sio = socketio.AsyncServer(async_mode='aiohttp', cors_allowed_origins='*')
app = web.Application()
sio.attach(app)

# Register HTTP routes
auth_routes(app)
system_routes(app)

# Register Socket.IO events
# register_socketio_events(sio)

# Initialize database
async def init_db():
    try:
        Base.metadata.create_all(bind=engine)
        print("Database initialized.")
    except Exception as e:
        print(f"Error initializing the database: {e}")

# Start the server
async def start_app():
    await init_db()
    return app

if __name__ == '__main__':
    web.run_app(start_app(), host='0.0.0.0', port=8882)
