import os
from dotenv import load_dotenv
import pytz

# Global configuration settings
GLOBAL_TIMEZONE = pytz.timezone('Asia/Kolkata')

# Load environment variables from the .env file
load_dotenv()

# Retrieve settings from environment variables
DEBUG = os.getenv("DEBUG", "False") == "True"
DATABASE_TYPE = os.getenv("DATABASE_TYPE", "sqlite")

# Default database credentials
DB_NAME = os.getenv("DB_NAME", "db.sqlite3")  # Default for SQLite
DB_USER = os.getenv("DB_USER", None)  # Default to None
DB_PASSWORD = os.getenv("DB_PASSWORD", None)  # Default to None
DB_HOST = os.getenv("DB_HOST", "localhost")  # Default host
DB_PORT = os.getenv("DB_PORT", "3306")  # Default port

# Only update DB_NAME for non-SQLite types
if DATABASE_TYPE in ['mysql', 'postgresql']:
    if not DB_NAME or not DB_USER or not DB_PASSWORD:
        raise ValueError("DB_NAME, DB_USER, and DB_PASSWORD must be set for MySQL or PostgreSQL.")

FIREBASE_CREDENTIALS_PATH = os.getenv("FIREBASE_CREDENTIALS_PATH")

# Log the configuration for debugging
print(f"Database Configuration: {DATABASE_TYPE}")
print(f"DEBUG Mode: {'Enabled' if DEBUG else 'Disabled'}")

TRANSMIT_DATA = {
    "isValid": False,
    "status": "ERROR",
    "data": [],
    "message": "Please check the provided Data",
    "errorList": []
}

# Redis Configuration
REDIS_HOST = os.getenv('REDIS_HOST', 'localhost')
REDIS_PORT = int(os.getenv('REDIS_PORT', 6379))
REDIS_DB = int(os.getenv('REDIS_DB', 0))
REDIS_PASSWORD = os.getenv('REDIS_PASSWORD', None)

# SMTP configuration
SMTP_SERVER = os.getenv("SMTP_SERVER", None)
SMTP_PORT = int(os.getenv("SMTP_PORT", 587))
SMTP_USERNAME = os.getenv("SMTP_USERNAME", None)
SMTP_PASSWORD = os.getenv("SMTP_PASSWORD", None)