import smtplib
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart
from settings import SMTP_SERVER, SMTP_PORT, SMTP_USERNAME, SMTP_PASSWORD  # Import SMTP settings

async def send_welcome_email(email, username):
    msg = MIMEMultipart()
    msg['From'] = SMTP_USERNAME  # Use SMTP_USERNAME from settings
    msg['To'] = email
    msg['Subject'] = "Welcome to Our Service!"

    body = f"Hello {username},\n\nThank you for signing up!"
    msg.attach(MIMEText(body, 'plain'))

    try:
        # Establish a secure session with SMTP server
        with smtplib.SMTP(SMTP_SERVER, SMTP_PORT) as server:
            server.starttls()  # Start TLS for security
            server.login(SMTP_USERNAME, SMTP_PASSWORD)  # Log in to the SMTP server
            server.send_message(msg)  # Send the email

        print(f"Welcome email sent to {email}")
    except smtplib.SMTPException as smtp_err:
        print(f"SMTP error occurred: {smtp_err}")
    except Exception as e:
        print(f"Failed to send email: {e}")

async def send_otp_email(email, otp):
    """Send an OTP email to the specified email address."""
    msg = MIMEMultipart()
    msg['From'] = SMTP_USERNAME  # Use SMTP_USERNAME from settings
    msg['To'] = email
    msg['Subject'] = "Your OTP Code"

    body = f"Your OTP code is: {otp}\n\nPlease use this code to complete your registration."
    msg.attach(MIMEText(body, 'plain'))

    try:
        # Establish a secure session with SMTP server
        with smtplib.SMTP(SMTP_SERVER, SMTP_PORT) as server:
            server.starttls()  # Start TLS for security
            server.login(SMTP_USERNAME, SMTP_PASSWORD)  # Log in to the SMTP server
            server.send_message(msg)  # Send the email

        print(f"OTP email sent to {email}")
    except smtplib.SMTPException as smtp_err:
        print(f"SMTP error occurred: {smtp_err}")
    except Exception as e:
        print(f"Failed to send OTP email: {e}")
